def ranktier(rank):
    if rank == 'null':
        print("This profile has not yet calibrated!")
        return None

    if type(rank) is int or type(rank) is float:
        rank = str(rank)

    if not all([rank.isdigit(), len(rank) == 2]):
        print("Something went wrong!\nRank input: %s\n" % rank)
        return None

    return getrank(rank)


def getrank(rank):
    readable_rank = []

    ranks = { "1" : "Herald"
            , "2" : "Guardian"
            , "3" : "Crusader"
            , "4" : "Archon"
            , "5" : "Ancient"
            , "6" : "Legend"
            , "7" : "Divine" }

    readable_rank.append("[%s]" % rank[1])

    return "{} [{}]".format(ranks[rank[0]], rank[1])



# -*- coding:utf-8 -*-

from setuptools import setup

setup(name="ranktier",
	version="1.0",
	description="A Dota rank tier converter",
	long_description="Ranktier turns two-digit rank tier numbers into human-readable output.",
	url="https://github.com/marcusmunch/ranktier",
	classifiers=[
		"Development Status :: 5 - Production/Stable",
		"License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
		"Natural Language :: English",
		"Programming Language :: Python :: 2.7"],
	author="Marcus Grünewald",
	author_email="marcus@marcusmunch.dk",
	packages=["ranktier"])